@@ -15,18 +15,16 @@ methods returning instances of ``QIcon``.
 
 # Standard library imports
 from __future__ import print_function
+import hashlib
 import json
 import os
-import hashlib
 import warnings
 
 # Third party imports
-from qtpy.QtCore import QObject, QPoint, QRect, Qt
+from qtpy.QtCore import QByteArray, QObject, QPoint, QRect, Qt
 from qtpy.QtGui import (QColor, QFont, QFontDatabase, QIcon, QIconEngine,
-                        QPainter, QPixmap, QTransform)
+                        QPainter, QPixmap, QTransform, QPalette)
 from qtpy.QtWidgets import QApplication
-from six import unichr
-
 
 # Linux packagers, please set this to True if you want to make qtawesome
 # use system fonts
@@ -35,16 +33,37 @@ SYSTEM_FONTS = False
 # MD5 Hashes for font files bundled with qtawesome:
 MD5_HASHES = {
     'fontawesome4.7-webfont.ttf': 'b06871f281fee6b241d60582ae9369b9',
-    'fontawesome5-regular-webfont.ttf': '6a745dc6a0871f350b0219f5a2678838',
-    'fontawesome5-solid-webfont.ttf': 'acf50f59802f20d8b45220eaae532a1c',
-    'fontawesome5-brands-webfont.ttf': 'ed2b8bf117160466ba6220a8f1da54a4',
+    'fontawesome5-regular-webfont.ttf': '808833867034fb67a4a86dd2155e195d',
+    'fontawesome5-solid-webfont.ttf': '139654bb0acaba6b00ae30d5faf3d02f',
+    'fontawesome5-brands-webfont.ttf': '085b1dd8427dbeff10bd55410915a3f6',
     'elusiveicons-webfont.ttf': '207966b04c032d5b873fd595a211582e',
-    'materialdesignicons-webfont.ttf': 'f558fb5cc12a31989a7e4048b4fba71a',
+    'materialdesignicons5-webfont.ttf': 'b7d40e7ef80c1d4af6d94902af66e524',
+    'materialdesignicons6-webfont.ttf': '9a2f455e7cbce011368aee95d292613b',
+    'phosphor.ttf': '5b8dc57388b2d86243566b996cc3a789',
+    'remixicon.ttf': '888e61f04316f10bddfff7bee10c6dd0',
+    'codicon.ttf': 'ca2f9e22cee3a59156b3eded74d87784',
 }
 
+
+def text_color():
+    try:
+        palette = QApplication.instance().palette()
+        return palette.color(QPalette.Active, QPalette.Text)
+    except AttributeError:
+        return QColor(50, 50, 50)
+
+
+def text_color_disabled():
+    try:
+        palette = QApplication.instance().palette()
+        return palette.color(QPalette.Disabled, QPalette.Text)
+    except AttributeError:
+        return QColor(150, 150, 150)
+
+
 _default_options = {
-    'color': QColor(50, 50, 50),
-    'color_disabled': QColor(150, 150, 150),
+    'color': text_color,
+    'color_disabled': text_color_disabled,
     'opacity': 1.0,
     'scale_factor': 1.0,
 }
@@ -110,8 +129,18 @@ class CharIconPainter:
         }
 
         color, char = color_options[state][mode]
+        alpha = None
 
-        painter.setPen(QColor(color))
+        # If color comes as a tuple, it means we need to set alpha on it.
+        if isinstance(color, tuple):
+            alpha = color[1]
+            color = color[0]
+
+        qcolor = QColor(color)
+        if alpha:
+            qcolor.setAlpha(alpha)
+
+        painter.setPen(qcolor)
 
         # A 16 pixel-high icon yields a font size of 14, which is pixel perfect
         # for font-awesome. 16 * 0.875 = 14
@@ -172,7 +201,7 @@ class CharIconEngine(QIconEngine):
     """Specialization of QIconEngine used to draw font-based icons."""
 
     def __init__(self, iconic, painter, options):
-        super(CharIconEngine, self).__init__()
+        super().__init__()
         self.iconic = iconic
         self.painter = painter
         self.options = options
@@ -205,10 +234,11 @@ class IconicFont(QObject):
             - Optionally, the directory containing these files. When not
               provided, the files will be looked for in ``./fonts/``.
         """
-        super(IconicFont, self).__init__()
+        super().__init__()
         self.painter = CharIconPainter()
         self.painters = {}
         self.fontname = {}
+        self.fontids = {}
         self.charmap = {}
         self.icon_cache = {}
         for fargs in args:
@@ -234,7 +264,16 @@ class IconicFont(QObject):
         def hook(obj):
             result = {}
             for key in obj:
-                result[key] = unichr(int(obj[key], 16))
+                try:
+                    result[key] = chr(int(obj[key], 16))
+                except ValueError:
+                    if int(obj[key], 16) > 0xffff:
+                        # ignoring unsupported code in Python 2.7 32bit Windows
+                        # ValueError: chr() arg not in range(0x10000)
+                        pass
+                    else:
+                        raise FontError(u'Failed to load character '
+                                        '{0}:{1}'.format(key, obj[key]))
             return result
 
         if directory is None:
@@ -243,10 +282,14 @@ class IconicFont(QObject):
 
         # Load font
         if QApplication.instance() is not None:
-            id_ = QFontDatabase.addApplicationFont(os.path.join(directory,
-                                                                ttf_filename))
+            with open(os.path.join(directory, ttf_filename), 'rb') as font_data:
+                id_ = QFontDatabase.addApplicationFontFromData(QByteArray(font_data.read()))
+            font_data.close()
+
             loadedFontFamilies = QFontDatabase.applicationFontFamilies(id_)
-            if(loadedFontFamilies):
+
+            if loadedFontFamilies:
+                self.fontids[prefix] = id_
                 self.fontname[prefix] = loadedFontFamilies[0]
             else:
                 raise FontError(u"Font at '{0}' appears to be empty. "
@@ -304,7 +347,9 @@ class IconicFont(QObject):
         return self.icon_cache[cache_key]
 
     def _parse_options(self, specific_options, general_options, name):
-        options = dict(_default_options, **general_options)
+        live_dict = {k: v() if callable(v) else v for k, v in _default_options.items()}
+
+        options = dict(live_dict, **general_options)
         options.update(specific_options)
 
         # Handle icons for modes (Active, Disabled, Selected, Normal)
@@ -381,7 +426,8 @@ class IconicFont(QObject):
 
     def font(self, prefix, size):
         """Return a QFont corresponding to the given prefix and size."""
-        font = QFont(self.fontname[prefix])
+        font = QFont()
+        font.setFamily(self.fontname[prefix])
         font.setPixelSize(round(size))
         if prefix[-1] == 's':  # solid style
             font.setStyleName('Solid')
